<style>
	html, body, #the_page, #the_page > .container, #content {
		height: 100%;
	}
	
	#the_page > .container ~ .container {
		height: initial;
	}
	
	#mapcontainer {
		position: relative;
		width: 100%;
		height: 90%;
		border: 1px solid #d3d3d3;
	}
	
	/* Always set the map height explicitly to define the size of the div element that contains the map. */
	#map {
		overflow: hidden;
		position: absolute !important;
		top: 0;
		left: 0px;
		right: 0px;
		bottom: 0;
	}
	
	#rightPanel {
		width: {$rightPanelWidth}px;
		max-width: 100%;
		height: 100%;
		overflow: auto;
		right: 0;
		top: 0;
		position: absolute;
		display: none;
	}
	
	.rightPanelContent {
		background-color: #ffffff;
		padding-left: 20px;
		overflow: hidden;
		display: none;
	}
	
	.catName {
		font-weight: bold;
	}
	
	.catComment {
		
	}
	
	.mapPhotos {
		text-align: center;
	}
</style>
<div id="mapcontainer">
	<div id="map"></div>
	<div id="rightPanel">
		{foreach from=$map_points item=map_point}
			<div class='rightPanelContent' id='rightPanelContent{$map_point.id}'>
				<img src='plugins/TravelMap/images/close.png' alt='X' style='margin-left: -20px;' onclick='unselectPoint({$map_point.id})' /><br/>
				<div id='category{$map_point.id}'>
					<p class="catName">{$map_point.name}</p>
					<p class="catComment">{$map_point.comment}</p>
					{$map_point.display_photos}
				</div>
			</div>
		{/foreach}
	</div>
</div>
<img src='plugins/TravelMap/images/close.png' style='display: none;'/>
<img src='plugins/TravelMap/images/markerSelected.png' style='display: none;'/>
<script>
	var map;
	var markers;
	var markerImage;
	var markerSelectedImage;
	var selectedPoint = -1;
	
	function wait(ms) {
		var start = new Date().getTime();
		var end = start;
		while(end < start + ms) {
			end = new Date().getTime();
		}
	}
	
	function initMap() {
		map = new google.maps.Map(document.getElementById('map'), {
		  mapTypeId: 'terrain'
		});

		var coords;
		var path;
		markers = {};
		var bounds = new google.maps.LatLngBounds();
		
		markerImage = {
			url: 'plugins/TravelMap/images/marker.png',
			size: new google.maps.Size(11, 11),
			origin: new google.maps.Point(0, 0),
			anchor: new google.maps.Point(6, 6)
		};
		
		markerSelectedImage = {
			url: 'plugins/TravelMap/images/markerSelected.png',
			size: new google.maps.Size(11, 11),
			origin: new google.maps.Point(0, 0),
			anchor: new google.maps.Point(6, 6)
		};

		
		{foreach from=$map_points item=map_point}
			var pointLocation = {};
			var precLocation = {};
			
			pointLocation['{$map_point.id}'] = { lat: {$map_point.latitude}, lng: {$map_point.longitude} };
			bounds.extend(pointLocation['{$map_point.id}']);
			map.fitBounds(bounds);
			map.panToBounds(bounds);
			{if isset($map_point.prec)}
				precLocation['{$map_point.id}'] = { lat: {$map_point.prec.latitude}, lng: {$map_point.prec.longitude} };
				path = new google.maps.Polyline({ path: [precLocation['{$map_point.id}'], pointLocation['{$map_point.id}']], geodesic: true, strokeColor: '#{$route_color}', strokeOpacity: 1.0, strokeWeight: 2 });
				path.setMap(map);
			{/if}
			{if isset($map_point.category)}
				markers['{$map_point.id}'] = new google.maps.Marker({ position: pointLocation['{$map_point.id}'], map: map, title: '{$map_point.name}', icon: markerImage });
				markers['{$map_point.id}'].addListener('mousedown', function() { togglePoint('{$map_point.id}'); });
			{/if}
		{/foreach}
	}
	
	function unselectPoint(pointId) {
		selectedPoint = -1;
		
		markers[pointId].setIcon(markerImage);
		
		document.getElementById('rightPanelContent'+pointId).classList.remove('rightPanelContentSelected');
		document.getElementById('map').style.right="0px";
		document.getElementById('rightPanel').style.display="none";
		document.getElementById('rightPanelContent'+pointId).style.display="none";
		google.maps.event.trigger(map, 'resize');
	}
	
	function selectPoint(pointId) {
		if(selectedPoint!=-1) {
			unselectPoint(selectedPoint);
		}
		selectedPoint = pointId;
		
		markers[pointId].setIcon(markerSelectedImage);
		
		document.getElementById('rightPanelContent'+pointId).classList.add('rightPanelContentSelected');
		
		document.getElementById('map').style.right="{$rightPanelWidth}px";
		document.getElementById('rightPanel').style.display="block";
		document.getElementById('rightPanelContent'+pointId).style.display="block";
		document.getElementById('rightPanel').scrollTop = 0;
		google.maps.event.trigger(map, 'resize');
		
		{if !$load_all_images}
			var imagesToLoad = document.getElementById('rightPanelContent'+pointId).getElementsByTagName("img");
			[].forEach.call(imagesToLoad, function(imageToLoad) {
				if(imageToLoad.getAttribute("src")==null && imageToLoad.getAttribute("_src")!=null) {
					imageToLoad.src = imageToLoad.getAttribute("_src");
				}
			});
		{/if}
	}
	
	function togglePoint(pointId) {
		if(selectedPoint==pointId) {
			unselectPoint(pointId);
		}
		else {
			selectPoint(pointId);
		}
	}
</script>
<script async defer src="https://maps.googleapis.com/maps/api/js?key={$google_maps_api_key}&callback=initMap"></script>